@@ -4,7 +4,7 @@ from subprocess import call
 
 seconds_listen_channel = 5*60 # seconds
 my_username = u"fenton"
-
+debug = True
 monitored_channels = {} # "channel_name": time_i_last_chatted
 
 def generate_actions_from_irc_message(args,printer):
@@ -36,6 +36,8 @@ def generate_actions_from_irc_message(args,printer):
 
     if from_me:
         monitored_channels[channel] = time.time()
+        if debug:
+            printer("Now monitoring channel: " + channel, str(monitored_channels[channel])
 
     monitoring_channel = monitored_channel( channel, monitored_channels )
     if not to_me and not from_me and channel == "test":
@@ -48,6 +50,9 @@ def generate_actions_from_irc_message(args,printer):
                              u"arguments": {u"alert_title": alert_title, 
                                            u"alert_message": alrt_msg,
                                            u"urgency": u"low"}} )
+        if debug:
+            printer("Monitoring Channel Msg" + channel, str(monitored_channels)
+                    
     return actions_todo
 
 
